@@ -115,8 +115,18 @@ static void add_startupnotify_or_execute_options_to_context_menu (      GtkWidge
                                                                   const guint8        number_of_opts, 
                                                                   const gchar       **options_array)
 {
-    const gchar *menu_item_txts_exe_opts[] = { N_("Add Prompt"), N_("Add Command"), N_("Add Startupnotify") };
-    const gchar *menu_item_txts_snotify_opts[] = { N_("Add Enabled"), N_("Add Name"), N_("Add WM_CLASS") }; // Without Icon, because of context used below.
+    const gchar *menu_item_txts_exe_opts[] = { // Translation note: Do not translate "Prompt". This is for a context menu.
+	                                           N_("Add Prompt"), 
+	                                           // Translation note: Do not translate "Command". This is for a context menu.
+	                                           N_("Add Command"),
+											   // Translation note: Do not translate "Startupnotify". This is for a context menu.
+											   N_("Add Startupnotify") };
+    const gchar *menu_item_txts_snotify_opts[] = { // Translation note: Do not translate "Enabled". This is for a context menu.
+	                                               N_("Add Enabled"), 
+	                                               // Translation note: Do not translate "Name". This is for a context menu.
+	                                               N_("Add Name"),
+												   // Translation note: Do not translate "WM_CLASS". This is for a context menu.
+												   N_("Add WM_CLASS") }; // Without Icon, because of context used below.
     g_autofree gboolean *opts_exist = g_malloc0 (sizeof (gboolean) * number_of_opts); // Initialize all elements to FALSE.
     GtkWidget *menu_item;
     gboolean add_new_callback;
@@ -125,6 +135,7 @@ static void add_startupnotify_or_execute_options_to_context_menu (      GtkWidge
 
     for (guint8 opts_cnt = 0; opts_cnt < number_of_opts; ++opts_cnt) {    
         if (!opts_exist[opts_cnt]) {
+			// Translation note: Do not translate "Icon". This is for a context menu.
             menu_item = gtk_menu_item_new_with_label ((startupnotify_opts) ? ((opts_cnt < number_of_opts - 1) ? _(menu_item_txts_snotify_opts[opts_cnt]) : C_("Context Menu|Child of Startupnotify", "Add Icon")) : 
                                                       _(menu_item_txts_exe_opts[opts_cnt]));
 
@@ -232,7 +243,9 @@ void create_context_menu (GdkEventButton *event)
                     create_cm_headline (context_menu, _(" Icon")); // Items have "Icon" and "Action" as context menu headlines.
                 }
 
-                menu_item = gtk_menu_item_new_with_label ((ks.txt_fields[ICON_PATH_TXT]) ? _("Change Icon") : C_("Context Menu|Menu or Item", "Add Icon"));
+                menu_item = gtk_menu_item_new_with_label ((ks.txt_fields[ICON_PATH_TXT]) ? _("Change Icon") : 
+                                                                                           // Translation note: This is for a context menu
+                                                                                           C_("Context Menu|Menu or Item", "Add Icon"));
                 g_signal_connect (menu_item, "activate", G_CALLBACK (icon_choosing_by_button_or_context_menu), NULL);
                 gtk_menu_shell_append (GTK_MENU_SHELL (context_menu), menu_item);
                 if (ks.txt_fields[ICON_PATH_TXT]) {
@@ -263,6 +276,7 @@ void create_context_menu (GdkEventButton *event)
                         const gint number_of_chldn_of_gp = gtk_tree_model_iter_n_children (ks.ts_model, &grandparent);
 
                         if (STREQ (ks.txt_fields[TYPE_TXT], "option block") && number_of_chldn_of_gp < NUMBER_OF_EXECUTE_OPTS) {
+							// Translation note: Do not translate "Startupnotify"
                             gchar *headline_txt = ngettext (" Startupnotify Option", " Startupnotify Options", 
                                                             (gtk_tree_model_iter_n_children (ks.ts_model, &parent) == NUMBER_OF_STARTUPNOTIFY_OPTS - 1));
 
@@ -299,6 +313,7 @@ void create_context_menu (GdkEventButton *event)
                         if (STREQ (ks.txt_fields[TYPE_TXT], "action") || 
                             (STREQ (ks.txt_fields[TYPE_TXT], "option block") && 
                             gtk_tree_model_iter_n_children (ks.ts_model, &ks.iter) < NUMBER_OF_STARTUPNOTIFY_OPTS)) {
+							// Translation note: Do not translate "Execute"
                             gchar *headline_txt = ngettext (" Execute Option", " Execute Options", 
                                                             (gtk_tree_model_iter_n_children (ks.ts_model, &parent) == NUMBER_OF_EXECUTE_OPTS - 1));
 
@@ -322,10 +337,19 @@ void create_context_menu (GdkEventButton *event)
                     streq_any (ks.txt_fields[MENU_ELEMENT_TXT], "Exit", "SessionLogout", "Restart", NULL) && 
                     !gtk_tree_model_iter_has_child (ks.ts_model, &ks.iter)) {
                     const gboolean restart = STREQ (ks.txt_fields[MENU_ELEMENT_TXT], "Restart");
+					// Translation note: Do not translate "Restart"
                     create_cm_headline (context_menu, (restart) ? _(" Restart Option") : 
                                         (STREQ (ks.txt_fields[MENU_ELEMENT_TXT], "Exit") ? 
-                                        _(" Exit Option") : _(" SessionLogout Option")));
-                    menu_item = gtk_menu_item_new_with_label ((restart) ? _("Add Command") : _("Add Prompt"));
+										// Translation note: Do not translate "Exit"
+                                        _(" Exit Option") : 
+										// Translation note: Do not translate "SessionLogout"
+										_(" SessionLogout Option")));
+										                                  
+                    menu_item = gtk_menu_item_new_with_label ((restart) ? 
+					                                         // Translation note: Do not translate "Command". This is for a context menu.
+					                                         _("Add Command") : 
+					                                         // Translation note: Do not translate "Prompt". This is for a context menu.
+					                                         _("Add Prompt"));
                     g_signal_connect_swapped (menu_item, "activate", G_CALLBACK (add_new), (restart) ? "command" : "prompt");
                     gtk_menu_shell_append (GTK_MENU_SHELL (context_menu), menu_item);
 
@@ -340,7 +364,16 @@ void create_context_menu (GdkEventButton *event)
                 }
 
                 for (guint8 actions_cnt = 0; actions_cnt < NUMBER_OF_ACTIONS; ++actions_cnt) {
-                    const gchar *menu_item_txts[] = { N_("Add Execute"), N_("Add Exit"), N_("Add Reconfigure"), N_("Add Restart"), N_("Add SessionLogout") };
+                    const gchar *menu_item_txts[] = { // Translation note: Do not translate "Execute". This is for a context menu.
+					                                  N_("Add Execute"), 
+					                                  // Translation note: Do not translate "Exit". This is for a context menu.
+					                                  N_("Add Exit"), 
+													  // Translation note: Do not translate "Reconfigure". This is for a context menu.
+													  N_("Add Reconfigure"), 
+													  // Translation note: Do not translate "Restart". This is for a context menu.
+													  N_("Add Restart"), 
+													  // Translation note: Do not translate "SessionLogout". This is for a context menu.
+													  N_("Add SessionLogout") };
 
                     menu_item = gtk_menu_item_new_with_label (_(menu_item_txts[actions_cnt]));
 
@@ -365,7 +398,14 @@ void create_context_menu (GdkEventButton *event)
     */
     if (!path || ks.txt_fields[ELEMENT_VISIBILITY_TXT]) {
         const gchar *basic_menu_elements[] = { "menu", "pipe menu", "item", "separator" };
-        const gchar *add_basic_menu_elements_for_cm[] = { N_("Add Menu"), N_("Add Pipe Menu"), N_("Add Item"), N_("Add Separator") };
+        const gchar *add_basic_menu_elements_for_cm[] = { // Translation note: This is for a context menu.
+		                                                  N_("Add Menu"), 
+														  // Translation note: This is for a context menu.
+														  N_("Add Pipe Menu"), 
+														  // Translation note: This is for a context menu.
+														  N_("Add Item"), 
+														  // Translation note: This is for a context menu.
+														  N_("Add Separator") };
         const gchar *basic_menu_elements_for_cm[] = { N_("Menu"), N_("Pipe Menu"), N_("Item"), N_("Separator") };
         const gchar *items[] = { "item+Execute", "item+Exit", "item+Reconfigure", "item+Restart", "item+SessionLogout" };
         enum { MENU, PIPE_MENU, ITEM, SEPARATOR };
@@ -376,6 +416,7 @@ void create_context_menu (GdkEventButton *event)
 
         if (!path) {
             gtk_tree_selection_unselect_all (selection);
+            // Translation note: "Top Level" refers to the top level of a tree view in a GUI. This is for a context menu.
             create_cm_headline (context_menu, _(" Add at Top Level"));
         }
 
@@ -469,7 +510,9 @@ void create_context_menu (GdkEventButton *event)
                                                                        ngettext ("Expand Row Recursively", "Expand Rows Recursively", 
                                                                                  (number_of_selected_rows == 1)) : 
                                                                        ((exp_status_changes_cnt == CM_IMMEDIATE) ? 
-                                                                        ngettext ("Expand Row (Imd. Ch. Only)", "Expand Rows (Imd. Ch. Only)", 
+																	    // Translation note: "Imd. Ch. Only" means "immediate children only"
+                                                                        ngettext ("Expand Row (Imd. Ch. Only)", 
+																		          "Expand Rows (Imd. Ch. Only)", 
                                                                                   (number_of_selected_rows == 1)) :
                                                                         ngettext ("Collapse Row", "Collapse Rows", (number_of_selected_rows == 1))));
                     menu_item = gtk_menu_item_new_with_label (menu_item_txt);
